@@ -23,22 +23,23 @@ CONSTANT_TYPE_LONG_ARRAY = -17
 CONSTANT_TYPE_FLOAT_ARRAY = -18
 CONSTANT_TYPE_DOUBLE_ARRAY = -19
 CONSTANT_TYPE_STRING_ARRAY = -20
+CONSTANT_TYPE_UUID = -21
 
 # ------------------------------------------------------------
 # DEFAULT SERIALIZERS
 
-JAVA_DEFAULT_TYPE_CLASS = -21
-JAVA_DEFAULT_TYPE_DATE = -22
-JAVA_DEFAULT_TYPE_BIG_INTEGER = -23
-JAVA_DEFAULT_TYPE_BIG_DECIMAL = -24
-JAVA_DEFAULT_TYPE_ENUM = -25
-JAVA_DEFAULT_TYPE_ARRAY_LIST = -26
-JAVA_DEFAULT_TYPE_LINKED_LIST = -27
+JAVA_DEFAULT_TYPE_CLASS = -24
+JAVA_DEFAULT_TYPE_BIG_INTEGER = -26
+JAVA_DEFAULT_TYPE_BIG_DECIMAL = -27
+JAVA_DEFAULT_TYPE_ARRAY = -28
+JAVA_DEFAULT_TYPE_ARRAY_LIST = -29
+JAVA_DEFAULT_TYPE_LINKED_LIST = -30
+JAVA_DEFAULT_TYPE_LOCAL_DATE = -51
+JAVA_DEFAULT_TYPE_LOCAL_TIME = -52
+JAVA_DEFAULT_TYPE_LOCAL_DATE_TIME = -53
+JAVA_DEFAULT_TYPE_OFFSET_DATE_TIME = -54
 JAVASCRIPT_JSON_SERIALIZATION_TYPE = -130
 
-# NUMBER OF CONSTANT SERIALIZERS...
-CONSTANT_SERIALIZERS_LENGTH = 28
-
 # ------------------------------------------------------------
 # JAVA SERIALIZATION
 
