@@ -1,12 +1,19 @@
+import datetime
+import decimal
 import uuid
 
+from hazelcast import six
 from hazelcast.serialization.base import BaseSerializationService
-from hazelcast.serialization.objects import ReliableTopicMessage
+from hazelcast.serialization.objects import (
+    CanonicalizingHashSet,
+    IdentifiedAddress,
+    IdentifiedMapEntry,
+    ReliableTopicMessage,
+)
 from hazelcast.serialization.portable.classdef import FieldType
 from hazelcast.serialization.portable.context import PortableContext
 from hazelcast.serialization.portable.serializer import PortableSerializer
 from hazelcast.serialization.serializer import *
-from hazelcast import six
 
 DEFAULT_OUT_BUFFER_SIZE = 4 * 1024
 
@@ -57,7 +64,18 @@ class SerializationServiceV1(BaseSerializationService):
 
     def _get_builtin_identified_factories(self):
         return {
-            ReliableTopicMessage.FACTORY_ID: {ReliableTopicMessage.CLASS_ID: ReliableTopicMessage}
+            ReliableTopicMessage.FACTORY_ID: {
+                ReliableTopicMessage.CLASS_ID: ReliableTopicMessage,
+            },
+            CanonicalizingHashSet.FACTORY_ID: {
+                CanonicalizingHashSet.CLASS_ID: CanonicalizingHashSet,
+            },
+            IdentifiedMapEntry.FACTORY_ID: {
+                IdentifiedMapEntry.CLASS_ID: IdentifiedMapEntry,
+            },
+            IdentifiedAddress.FACTORY_ID: {
+                IdentifiedAddress.CLASS_ID: IdentifiedAddress,
+            },
         }
 
     def _register_constant_serializers(self):
@@ -85,11 +103,16 @@ class SerializationServiceV1(BaseSerializationService):
         self._registry.register_constant_serializer(DoubleArraySerializer())
         self._registry.register_constant_serializer(StringArraySerializer())
         # EXTENSIONS
-        self._registry.register_constant_serializer(DateTimeSerializer(), datetime)
         self._registry.register_constant_serializer(BigIntegerSerializer())
+        self._registry.register_constant_serializer(BigDecimalSerializer(), decimal.Decimal)
         self._registry.register_constant_serializer(JavaClassSerializer())
+        self._registry.register_constant_serializer(ArraySerializer())
         self._registry.register_constant_serializer(ArrayListSerializer(), list)
         self._registry.register_constant_serializer(LinkedListSerializer())
+        self._registry.register_constant_serializer(LocalDateSerializer(), datetime.date)
+        self._registry.register_constant_serializer(LocalTimeSerializer(), datetime.time)
+        self._registry.register_constant_serializer(LocalDateTimeSerializer())
+        self._registry.register_constant_serializer(OffsetDateTimeSerializer(), datetime.datetime)
         self._registry.register_constant_serializer(
             HazelcastJsonValueSerializer(), HazelcastJsonValue
         )
